# Generated by Django 3.2.18 on 2023-04-13 18:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('common', '0037_migrate_email_verification'),
    ]

    operations = [
        migrations.DeleteModel(
            name='EmailVerification',
        ),
    ]
