# Generated by Django 3.2.13 on 2022-05-17 17:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('common', '0022_school_cleanup'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='school',
            options={},
        ),
        migrations.AddField(
            model_name='userprofile',
            name='aimmo_badges',
            field=models.CharField(blank=True, max_length=200, null=True),
        ),
    ]
