<!-- OneTrust Cookies Consent Notice start for codeforlife.education -->
{% if module_name == "default" %}
    <script type="text/javascript" src="https://cdn-ukwest.onetrust.com/consent/5da42396-cb12-4493-8d04-5179033cfbad/OtAutoBlock.js" ></script>
    <script src="https://cdn-ukwest.onetrust.com/scripttemplates/otSDKStub.js"  type="text/javascript" charset="UTF-8" data-domain-script="5da42396-cb12-4493-8d04-5179033cfbad" ></script>
    <script type="text/javascript">
        function OptanonWrapper() { }
    </script>
{% elif cookie_management_enabled %}
    <script type="text/javascript" src="https://cdn-ukwest.onetrust.com/consent/5da42396-cb12-4493-8d04-5179033cfbad-test/OtAutoBlock.js" ></script>
    <script src="https://cdn-ukwest.onetrust.com/scripttemplates/otSDKStub.js"  type="text/javascript" charset="UTF-8" data-domain-script="5da42396-cb12-4493-8d04-5179033cfbad-test" ></script>
    <script type="text/javascript">
        function OptanonWrapper() { }
    </script>
{% endif %}
<!-- OneTrust Cookies Consent Notice end for codeforlife.education -->
