# Generated by Django 3.2.18 on 2023-04-11 14:31

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("common", "0035_rename_lockout_fields"),
    ]

    operations = [
        migrations.RenameField(
            model_name="userprofile",
            old_name="awaiting_email_verification",
            new_name="is_verified",
        ),
    ]
