# Generated by Django 3.2.13 on 2022-04-29 17:00

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('common', '0020_class_is_active_and_null_access_code'),
    ]

    operations = [
        migrations.AddField(
            model_name='school',
            name='is_active',
            field=models.BooleanField(default=True),
        ),
        migrations.AlterField(
            model_name='school',
            name='postcode',
            field=models.CharField(max_length=10, null=True),
        ),
        migrations.AlterField(
            model_name='school',
            name='town',
            field=models.CharField(max_length=200, null=True),
        ),
    ]
