# Generated by Django 3.2.20 on 2023-11-06 16:04

from django.db import migrations
import django_countries.fields


class Migration(migrations.Migration):

    dependencies = [
        ('common', '0045_otp'),
    ]

    operations = [
        migrations.AlterField(
            model_name='school',
            name='country',
            field=django_countries.fields.CountryField(blank=True, max_length=2, null=True),
        ),
    ]
